package dk.nsp.xdscleanup.config;

import java.util.LinkedList;
import java.util.List;

import dk.nsp.xdscleanup.model.xds.TypeCode;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;

import dk.nsp.xdscleanup.model.DocumentTypeCleanupSpecification;
import dk.nsp.xdscleanup.service.CleanupService;
import dk.nsp.xdscleanup.service.RegistryCleanupService;
import dk.nsp.xdscleanup.service.RepositoryCleanupService;
import dk.nsp.xdscleanup.service.impl.CleanupServiceImpl;

@Configuration
@ComponentScan("dk.nsp.xdscleanup.config")
public class CleanupConfig {

	private static final String LOINC_OID = "2.16.840.1.113883.6.1";
	private static final String LOINC_APD_CODE = "39289-4";
	
	
	@Value("${deletion.batchsize}")
	private int batchSize;

	@Bean
	public CleanupService cleanupService(RegistryCleanupService registryCleanupService, RepositoryCleanupService repositoryCleanupService, List<DocumentTypeCleanupSpecification> documentTypeCleanupSpecifications) {
		return new CleanupServiceImpl(registryCleanupService, repositoryCleanupService, documentTypeCleanupSpecifications, batchSize);
	}
	
	@Bean
	public List<DocumentTypeCleanupSpecification> getDocumentTypeCleanupSpecifications() {
		// TODO: SDS-5387: Konfiguration af dokumenttyper til sletning
		List<DocumentTypeCleanupSpecification> documentTypeCleanupSpecifications = new LinkedList<DocumentTypeCleanupSpecification>();
		documentTypeCleanupSpecifications.add(new DocumentTypeCleanupSpecification(new TypeCode(LOINC_APD_CODE, LOINC_OID), 24));
		return documentTypeCleanupSpecifications;
	}
}
