package dk.nsp.xdscleanup.ws;

import java.io.IOException;
import java.util.List;

import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;

import dk.nsp.xdscleanup.util.HealthIndication;
import dk.nsp.xdscleanup.util.HealthIndicator;

@WebServlet(name="HealthServlet", urlPatterns={"/health"})
public class HealthServlet extends AbstractCleanupServlet {

	private static final long serialVersionUID = 1L;

	@Autowired
	private List<HealthIndicator> healthIndicators;

	public HealthServlet() {
	}

	public HealthServlet(List<HealthIndicator> healthIndicators) {
		this.healthIndicators = healthIndicators;
	}

	@Override
	public void doPost(HttpServletRequest request, HttpServletResponse response) throws IOException {
		reportHealth(request, response);
	}

	@Override
	public void doGet(HttpServletRequest request, HttpServletResponse response) throws IOException {
		reportHealth(request, response);
	}

	private void reportHealth(HttpServletRequest request, HttpServletResponse response) throws IOException {
		response.getOutputStream().write("{".getBytes());
		
		int status = 200;
		boolean isFirst = true;
		if (healthIndicators != null) {
			for (HealthIndicator healthIndicator : healthIndicators) {
				HealthIndication healthIndication = healthIndicator.getHealthInfo();
				if (healthIndication.getStatus() > status) {
					status = healthIndication.getStatus();
				}
				if (!isFirst) {
					response.getOutputStream().write(",".getBytes());
				} else {
					isFirst = false;
				}
				response.getOutputStream().write(healthIndication.getText().getBytes());
			}
		}

		response.getOutputStream().write("}".getBytes());
		response.setStatus(status);
	}
}