package dk.nsp.xdscleanup.ws;

import java.io.IOException;
import java.util.LinkedList;
import java.util.List;

import org.junit.Assert;
import org.junit.Test;
import org.mockito.Mockito;
import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.mock.web.MockHttpServletResponse;

import dk.nsp.xdscleanup.util.HealthIndication;
import dk.nsp.xdscleanup.util.HealthIndicator;

public class HealthServletTest {

	@Test
	public void testEmpty() throws IOException {

		// Given
		HealthServlet subject = new HealthServlet(null);
		MockHttpServletRequest request = new MockHttpServletRequest();
		MockHttpServletResponse response = new MockHttpServletResponse();

		// When
		subject.doGet(request, response);
		
		// Then
		Assert.assertEquals(200, response.getStatus());
		Assert.assertEquals("{}", response.getContentAsString());
	}
	
	@Test
	public void testWithHealthIndication() throws IOException {
		// Given
		List<HealthIndicator> listOfHealthIndications = new LinkedList<HealthIndicator>();
		HealthIndicator mockIndication1 = Mockito.mock(HealthIndicator.class);
		Mockito.when(mockIndication1.getHealthInfo()).thenReturn(new HealthIndication(500, "\"test1\": \"abc\""));
		HealthIndicator mockIndication2 = Mockito.mock(HealthIndicator.class);
		Mockito.when(mockIndication2.getHealthInfo()).thenReturn(new HealthIndication(200, "\"test2\": \"xyz\""));
		listOfHealthIndications.add(mockIndication1);
		listOfHealthIndications.add(mockIndication2);
		HealthServlet subject = new HealthServlet(listOfHealthIndications);
		MockHttpServletRequest request = new MockHttpServletRequest();
		MockHttpServletResponse response = new MockHttpServletResponse();

		// When
		subject.doGet(request, response);
		
		// Then
		Assert.assertEquals(500, response.getStatus());
		Assert.assertEquals("{\"test1\": \"abc\",\"test2\": \"xyz\"}", response.getContentAsString());
		
	}
}
