package dk.nsp.xdscleanup.service.impl;

import java.time.Instant;
import java.util.List;
import java.util.stream.Collectors;

import dk.nsp.xdscleanup.dao.NxrgDao;
import dk.nsp.xdscleanup.model.DeletedAssociation;
import dk.nsp.xdscleanup.model.DeletedDocumentEntry;
import dk.nsp.xdscleanup.model.DeletedSubmissionSet;
import dk.nsp.xdscleanup.model.xds.AssociationType;
import dk.nsp.xdscleanup.model.xds.ReferenceType;
import dk.nsp.xdscleanup.model.xds.TypeCode;
import dk.nsp.xdscleanup.service.RegistryCleanupService;
import org.springframework.transaction.annotation.Transactional;

public class RegistryCleanupServiceImpl implements RegistryCleanupService {
    private NxrgDao nxrgDao;
	
	public RegistryCleanupServiceImpl(NxrgDao nxrgDao) {
		this.nxrgDao = nxrgDao;
	}

    @Transactional(transactionManager = "tx-nxrg")
	public void deleteRegistryData(TypeCode typeCode, Instant olderThan, int batchSize) {
        // Rough sketch of implementation ...

        // 1. Retrieve a batch of DocumentEntries for deletion
        List<DeletedDocumentEntry> documentEntriesForDeletion = nxrgDao.getDocumentEntriesForDeletion(typeCode, olderThan, batchSize);

        // 2. Retrieve associations that refer to those DocumentEntries
        List<String> documentEntryUuids = documentEntriesForDeletion.stream().map(de -> de.getEntryUuid()).collect(Collectors.toList());
        List<DeletedAssociation> associationsForDeletion = nxrgDao.getAssociationsForDocumentEntries(documentEntryUuids);

        // 3. (maybe) Determine any other DocumentEntries referred to by the associations - do they need to be deleted as well?

        // 4. Determine SubmissionSets to delete
        List<String> submissionSetUuids = associationsForDeletion
                .stream()
                .filter(a -> a.getAssociationType() == AssociationType.HAS_MEMBER && a.getSourceType() == ReferenceType.SUBMISSION_SET)
                .map(a -> a.getEntryUuid())
                .collect(Collectors.toList());
        List<DeletedSubmissionSet> submissionSetsForDeletion = nxrgDao.filterEmptySubmissionSets(submissionSetUuids, documentEntryUuids);

        // 5. Delete those objects determined for deletion. The order matters here, since associations refer to other objects.
        nxrgDao.deleteAssociations(associationsForDeletion.stream().map(a -> a.getEntryUuid()).collect(Collectors.toList()));
        nxrgDao.deleteDocumentEntries(documentEntryUuids);
        nxrgDao.deleteSubmissionSets(submissionSetsForDeletion.stream().map(ss -> ss.getEntryUuid()).collect(Collectors.toList()));

        // 6. Mark the DocumentEntries as deleted in the status-table.
        nxrgDao.markDocumentEntriesDeletedFromRegistry(documentEntryUuids);
	}

	public void markDeletionComplete(List<DeletedDocumentEntry> deletedDocumentEntries) {
		// TODO Auto-generated method stub
		
	}

	public List<DeletedDocumentEntry> findDeletedDocumentEntries(int batchSize) {
		// TODO Auto-generated method stub
		return null;
	}


}
