package dk.nsp.xdscleanup.dao;

import java.util.List;

import javax.sql.DataSource;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Ignore;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringRunner;

import dk.nsp.xdscleanup.config.EmbeddedDatabaseConfiguration;
import dk.nsp.xdscleanup.dao.impl.NxrgDaoImpl;
import dk.nsp.xdscleanup.model.DeletedDocumentEntry;
import dk.nsp.xdscleanup.util.HealthIndication;

@RunWith(SpringRunner.class)
@ContextConfiguration(classes = {EmbeddedDatabaseConfiguration.class})
public class NxrgDaoTest {

	@Autowired
	DataSource dataSource;

	NxrgDaoImpl subject;
	
	@Before
	public void setup() {
		
		subject = new NxrgDaoImpl(dataSource);
	}
	
	@Test
    @Ignore
	public void test() {
		
		// Given
		
		// When
		List<DeletedDocumentEntry> deleted = subject.getDocumentEntriesForRepositoryDeletion(100);
		
		// Then
		Assert.assertNotNull(deleted);
	}

	
	@Test
	public void testHealthIndicationDatabaseOk() {
		
		// Given
		
		// When
		HealthIndication health = subject.getHealthInfo();
		
		// Then
		Assert.assertNotNull(health);
		Assert.assertEquals(200, health.getStatus());
		Assert.assertEquals("\"registry.db\": \"OK\"", health.getText());
	}

	@Test
    @Ignore("Ignore for now - datasource checking should probably use mocks instead.")
	public void testHealthIndicationDatabaseGone() {
		
		// Given
		JdbcTemplate template = new JdbcTemplate(dataSource);
		template.execute("DROP TABLE deleted_de");
		
		// When
		HealthIndication health = subject.getHealthInfo();
		
		// Then
		Assert.assertNotNull(health);
		Assert.assertEquals(500, health.getStatus());
		Assert.assertEquals("\"registry.db\": \"OK\"", health.getText());
	}

}
